#' @title natserv
#' @description Interface to NatureServe https://www.natureserve.org/
#' @name natserv-package
#' @importFrom jsonlite fromJSON
#' @importFrom crul HttpClient
#' @importFrom tibble as_tibble enframe
#' @aliases natserv
#' @docType package
#' @author Scott Chamberlain \email{myrmecocystus@@gmail.com}
#' @keywords package
NULL

#' A data.frame with 49 rows and 2 columns
#'
#' - state (character) state 2 letter abbreviation
#' - state_name (character) state full name
#'
#' @name nat_states
#' @docType data
#' @keywords data
NULL
