% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/natserv-package.R
\docType{package}
\name{natserv-package}
\alias{natserv-package}
\alias{natserv}
\title{natserv}
\description{
Interface to NatureServe https://www.natureserve.org/
}
\author{
Scott Chamberlain \email{myrmecocystus@gmail.com}
}
\keyword{package}
